@@ -21,7 +21,7 @@ impl State {
 #[notan_main]
 fn main() -> Result<(), String> {
     notan::init_with(init)
-        .set_config(DrawConfig)
+        .add_config(DrawConfig)
         .update(|app: &mut App, state: &mut State| state.count(60.0 * app.timer.delta_f32()))
         .draw(draw)
         .build()
