@@ -3,7 +3,7 @@ use notan::prelude::*;
 
 #[derive(AppState)]
 struct State {
-    egui_tex: egui::TextureId,
+    tex_id: egui::TextureId,
     img_size: egui::Vec2,
 }
 
@@ -12,36 +12,35 @@ impl State {
         let texture = gfx
             .create_texture()
             .from_image(include_bytes!("assets/rust-logo-256x256.png"))
+            .with_premultiplied_alpha()
             .build()
             .unwrap();
 
-        let img_size = egui::vec2(texture.width(), texture.height());
-        let egui_texture_id = gfx.register_egui_texture(&texture).unwrap();
+        let img_size: egui::Vec2 = texture.size().into();
+        let tex_id = gfx.egui_register_texture(&texture);
 
-        Self {
-            img_size,
-            egui_tex: egui_texture_id,
-        }
+        Self { img_size, tex_id }
     }
 }
 
 #[notan_main]
 fn main() -> Result<(), String> {
     notan::init_with(State::new)
-        .set_config(EguiConfig)
+        .add_config(EguiConfig)
         .draw(draw)
         .build()
 }
 
 fn draw(gfx: &mut Graphics, plugins: &mut Plugins, state: &mut State) {
-    let ctx = plugins
-        .get_mut::<EguiPlugin>()
-        .map(|mut plugin| plugin.create_context(Some(Color::BLACK)))
-        .unwrap();
-
-    egui::Window::new("Notan Texture").show(&ctx, |ui| {
-        ui.image(state.egui_tex, state.img_size);
+    let mut output = plugins.egui(|ctx| {
+        egui::Window::new("Notan Texture").show(ctx, |ui| {
+            ui.image(state.tex_id, state.img_size);
+        });
     });
 
-    gfx.render(&ctx);
+    output.clear_color(Color::BLACK);
+
+    if output.needs_repaint() {
+        gfx.render(&output);
+    }
 }
