@@ -9,7 +9,7 @@ struct State {
 #[notan_main]
 fn main() -> Result<(), String> {
     notan::init_with(State::default)
-        .set_config(DrawConfig)
+        .add_config(DrawConfig)
         .draw(draw)
         .build()
 }
@@ -21,7 +21,7 @@ fn draw(app: &mut App, gfx: &mut Graphics, state: &mut State) {
     let size = (400.0, 300.0);
 
     // Clone matrix
-    let mut m = glam::Mat3::IDENTITY;
+    let mut m = notan::math::Mat3::IDENTITY;
 
     // Draw the rect
     draw.rect((0.0, 0.0), size)
