@@ -11,6 +11,9 @@ pub use notan_utils as utils;
 #[cfg(feature = "default_backend")]
 pub use notan_backend as backend;
 
+#[cfg(feature = "audio")]
+pub use notan_audio as audio;
+
 #[cfg(feature = "log")]
 pub use notan_log as log;
 
