@@ -2,3 +2,6 @@ pub use crate::app::prelude::*;
 pub use crate::graphics::prelude::*;
 pub use crate::math::prelude::*;
 pub use notan_macro::{notan_main, AppState};
+
+#[cfg(feature = "audio")]
+pub use crate::audio::prelude::*;
